@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Module::CoreList;
 
-our $VERSION = '5.20200602';
+our $VERSION = '5.20200603';
 our %utilities;
 
 sub utilities {
@@ -1601,13 +1601,6 @@ my %delta = (
         removed => {
         }
     },
-    5.031012 => {
-        delta_from => 5.031011,
-        changed => {
-        },
-        removed => {
-        }
-    },
     5.028003 => {
         delta_from => 5.028002,
         changed => {
